# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://pythonpro.com.br/)

[![Build Status](https://app.travis-ci.com/Jessicabferreira/libpythonpro.svg?branch=main)](https://app.travis-ci.com/Jessicabferreira/libpythonpro)

Suportada a versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
.venv/Scripts/activate 
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:

```console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
